@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 use IO::String ();
 
@@ -19,6 +19,8 @@ sub implementations {
 		Benchmark::Featureset::ParamCheck::Implementation::ParamsCheck::Perl
 		Benchmark::Featureset::ParamCheck::Implementation::ParamsCheck::TypeTiny
 		Benchmark::Featureset::ParamCheck::Implementation::Perl
+		Benchmark::Featureset::ParamCheck::Implementation::PV
+		Benchmark::Featureset::ParamCheck::Implementation::PV::TypeTiny
 		Benchmark::Featureset::ParamCheck::Implementation::PVC::Moose
 		Benchmark::Featureset::ParamCheck::Implementation::PVC::Specio
 		Benchmark::Featureset::ParamCheck::Implementation::PVC::TypeTiny
@@ -131,6 +133,7 @@ B<< Parameter validation libraries: >>
 L<Data::Validator>,
 L<MooseX::Params::Validate>,
 L<Params::Check>,
+L<Params::Validate>,
 L<Params::ValidationCompiler>,
 L<Ref::Util::XS>,
 L<Type::Params>.
